==> haskell-config-ini-0.2.2.0-58-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-config-ini.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: config-ini
version: 0.2.2.0
id: config-ini-0.2.2.0-EY3SkEstpwDHxdqCFEM2eS
key: config-ini-0.2.2.0-EY3SkEstpwDHxdqCFEM2eS
license: BSD-3-Clause
copyright: ©2018 Getty Ritter
maintainer: Getty Ritter <config-ini@infinitenegativeutility.com>
author: Getty Ritter <config-ini@infinitenegativeutility.com>
homepage: https://github.com/aisamanra/config-ini
synopsis: A library for simple INI-based configuration files.
description:
    The @config-ini@ library is a set of small monadic languages
    for writing simple configuration languages with convenient,
    human-readable error messages.
    .
    > parseConfig :: IniParser (Text, Int, Bool)
    > parseConfig = section "NETWORK" $ do
    >   user <- field        "user"
    >   port <- fieldOf      "port" number
    >   enc  <- fieldFlagDef "encryption" True
    >   return (user, port, enc)
category: Configuration
abi: 3973d4597dc3913d91be0bf679cbdc53
exposed: True
exposed-modules:
    Data.Ini.Config Data.Ini.Config.Bidir Data.Ini.Config.Raw
import-dirs: /usr/lib/ghc-8.4.3/site-local/config-ini-0.2.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/config-ini-0.2.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/config-ini-0.2.2.0
hs-libraries: HSconfig-ini-0.2.2.0-EY3SkEstpwDHxdqCFEM2eS
depends:
    base-4.11.1.0 containers-0.5.11.0 text-1.2.3.0
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
    transformers-0.5.5.0 megaparsec-6.5.0-G2WzgYCrs1lBNj5cEcU9K4
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             megaparsec-6.5.0-G2WzgYCrs1lBNj5cEcU9K4=5351d8ca3bf428160f46fd0511026fdf
haddock-interfaces: /usr/share/doc/haskell-config-ini/html/config-ini.haddock
haddock-html: /usr/share/doc/haskell-config-ini/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-config-ini-0.2.2.0-69-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-config-ini.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: config-ini
version: 0.2.2.0
id: config-ini-0.2.2.0-Kkr9vsp8WPwLjhhACNHie1
key: config-ini-0.2.2.0-Kkr9vsp8WPwLjhhACNHie1
license: BSD-3-Clause
copyright: ©2018 Getty Ritter
maintainer: Getty Ritter <config-ini@infinitenegativeutility.com>
author: Getty Ritter <config-ini@infinitenegativeutility.com>
homepage: https://github.com/aisamanra/config-ini
synopsis: A library for simple INI-based configuration files.
description:
    The @config-ini@ library is a set of small monadic languages
    for writing simple configuration languages with convenient,
    human-readable error messages.
    .
    > parseConfig :: IniParser (Text, Int, Bool)
    > parseConfig = section "NETWORK" $ do
    >   user <- field        "user"
    >   port <- fieldOf      "port" number
    >   enc  <- fieldFlagDef "encryption" True
    >   return (user, port, enc)
category: Configuration
abi: 0ebe6b6ab71d2a0628a3fad42a6ae02d
exposed: True
exposed-modules:
    Data.Ini.Config Data.Ini.Config.Bidir Data.Ini.Config.Raw
import-dirs: /usr/lib/ghc-8.4.3/site-local/config-ini-0.2.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/config-ini-0.2.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/config-ini-0.2.2.0
hs-libraries: HSconfig-ini-0.2.2.0-Kkr9vsp8WPwLjhhACNHie1
depends:
    base-4.11.1.0 containers-0.5.11.0 text-1.2.3.0
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
    transformers-0.5.5.0 megaparsec-6.5.0-1GmkDOMeqYy5M1TwqrGPww
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             megaparsec-6.5.0-1GmkDOMeqYy5M1TwqrGPww=8a908e0ef40a76a2ec5fb51919b5a179
haddock-interfaces: /usr/share/doc/haskell-config-ini/html/config-ini.haddock
haddock-html: /usr/share/doc/haskell-config-ini/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
